@@ -154,7 +154,7 @@ def extract_tar(src_file=None, dst_path='./', file_obj=None, _mode='r:gz'):
         raise ValueError('Source file and byte data must fill in a')
 
     if src_file:
-        _content = read_binary_file(src_file)
+        _content = io.read_binary_file(src_file)
     elif file_obj:
         _content = file_obj
     else:
@@ -164,3 +164,26 @@ def extract_tar(src_file=None, dst_path='./', file_obj=None, _mode='r:gz'):
     _filenames = _obj.getnames()
     for _file in _filenames:
         _obj.extract(_file, dst_path)
+
+def extract_tar_obj(src_file=None, dst_path='./', file_obj=None, _mode='r:gz'):
+    """
+    默认解压gzip压缩包
+    :param _mode: r:gz r:bz2 r:xz
+    :param src_file: 源文件
+    :param dst_path: 解压路径
+    :param file_obj: 文件对象
+    :return:
+    """
+    if not src_file and not file_obj:
+        raise ValueError('Source file and byte data must fill in a')
+
+    if src_file:
+        _content = io.read_binary_file(src_file)
+    elif file_obj:
+        _content = file_obj
+    else:
+        raise BaseException('Unknown error getting file object')
+
+    _obj = tarfile.open(fileobj=BytesIO(_content), mode=_mode)
+    _filenames = _obj.getnames()
+    return _obj, _filenames
